@@ -4,12 +4,13 @@
 #'other \code{WikidataR} code, custom print methods are available; use \code{\link{str}}
 #'to manipulate and see the underlying structure of the data.
 #'
-#'@param id the ID number of the item or property you're looking for. This can be in
+#'@param id the ID number(s) of the item or property you're looking for. This can be in
 #'various formats; either a numeric value ("200"), the full name ("Q200") or
 #'even with an included namespace ("Property:P10") - the function will format
-#'it appropriately.
+#'it appropriately. This function is vectorised and will happily accept
+#'multiple IDs.
 #'
-#'@param ... further arguments to pass to httr's GET.
+#'@param \\dots further arguments to pass to httr's GET.
 #'
 #'@seealso \code{\link{get_random}} for selecting a random item or property,
 #'or \code{\link{find_item}} for using search functionality to pull out
@@ -29,17 +30,21 @@
 #'@export
 get_item <- function(id, ...){
   id <- check_input(id, "Q")
-  return(wd_query(id, ...))
+  output <- (lapply(id, wd_query, ...))
+  class(output) <- "wikidata"
+  return(output)
 }
 
 #'@rdname get_item
 #'@export
 get_property <- function(id, ...){
-  if(grepl("^P(?!r)",id, perl = TRUE)){
-    id <- paste0("Property:",id)
-  }
+  has_grep <- grepl("^P(?!r)",id, perl = TRUE)
+  id[has_grep] <- paste0("Property:", id[has_grep])
   id <- check_input(id, "Property:P")
-  return(wd_query(id, ...))
+  
+  output <- (lapply(id, wd_query, ...))
+  class(output) <- "wikidata"
+  return(output)
 }
 
 #'@title Retrieve randomly-selected Wikidata items or properties
@@ -50,7 +55,7 @@ get_property <- function(id, ...){
 #'
 #'@param limit how many random items to return. 1 by default, but can be higher.
 #'
-#'@param ... arguments to pass to httr's GET.
+#'@param \\dots arguments to pass to httr's GET.
 #'
 #'@seealso \code{\link{get_item}} for selecting a specific item or property,
 #'or \code{\link{find_item}} for using search functionality to pull out
@@ -91,7 +96,7 @@ get_random_property <- function(limit = 1, ...){
 #'
 #'@param limit the number of results to return; set to 10 by default.
 #'
-#'@param ... further arguments to pass to httr's GET.
+#'@param \\dots further arguments to pass to httr's GET.
 #'
 #'@seealso \code{\link{get_random}} for selecting a random item or property,
 #'or \code{\link{get_item}} for selecting a specific item or property.
